"""
Type annotations for stepfunctions service Client.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_stepfunctions.client import SFNClient

    session = Session()
    client: SFNClient = session.client("stepfunctions")
    ```
"""

from __future__ import annotations

import sys
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import (
    GetExecutionHistoryPaginator,
    ListActivitiesPaginator,
    ListExecutionsPaginator,
    ListMapRunsPaginator,
    ListStateMachinesPaginator,
)
from .type_defs import (
    CreateActivityInputTypeDef,
    CreateActivityOutputTypeDef,
    CreateStateMachineAliasInputTypeDef,
    CreateStateMachineAliasOutputTypeDef,
    CreateStateMachineInputTypeDef,
    CreateStateMachineOutputTypeDef,
    DeleteActivityInputTypeDef,
    DeleteStateMachineAliasInputTypeDef,
    DeleteStateMachineInputTypeDef,
    DeleteStateMachineVersionInputTypeDef,
    DescribeActivityInputTypeDef,
    DescribeActivityOutputTypeDef,
    DescribeExecutionInputTypeDef,
    DescribeExecutionOutputTypeDef,
    DescribeMapRunInputTypeDef,
    DescribeMapRunOutputTypeDef,
    DescribeStateMachineAliasInputTypeDef,
    DescribeStateMachineAliasOutputTypeDef,
    DescribeStateMachineForExecutionInputTypeDef,
    DescribeStateMachineForExecutionOutputTypeDef,
    DescribeStateMachineInputTypeDef,
    DescribeStateMachineOutputTypeDef,
    GetActivityTaskInputTypeDef,
    GetActivityTaskOutputTypeDef,
    GetExecutionHistoryInputTypeDef,
    GetExecutionHistoryOutputTypeDef,
    ListActivitiesInputTypeDef,
    ListActivitiesOutputTypeDef,
    ListExecutionsInputTypeDef,
    ListExecutionsOutputTypeDef,
    ListMapRunsInputTypeDef,
    ListMapRunsOutputTypeDef,
    ListStateMachineAliasesInputTypeDef,
    ListStateMachineAliasesOutputTypeDef,
    ListStateMachinesInputTypeDef,
    ListStateMachinesOutputTypeDef,
    ListStateMachineVersionsInputTypeDef,
    ListStateMachineVersionsOutputTypeDef,
    ListTagsForResourceInputTypeDef,
    ListTagsForResourceOutputTypeDef,
    PublishStateMachineVersionInputTypeDef,
    PublishStateMachineVersionOutputTypeDef,
    RedriveExecutionInputTypeDef,
    RedriveExecutionOutputTypeDef,
    SendTaskFailureInputTypeDef,
    SendTaskHeartbeatInputTypeDef,
    SendTaskSuccessInputTypeDef,
    StartExecutionInputTypeDef,
    StartExecutionOutputTypeDef,
    StartSyncExecutionInputTypeDef,
    StartSyncExecutionOutputTypeDef,
    StopExecutionInputTypeDef,
    StopExecutionOutputTypeDef,
    TagResourceInputTypeDef,
    TestStateInputTypeDef,
    TestStateOutputTypeDef,
    UntagResourceInputTypeDef,
    UpdateMapRunInputTypeDef,
    UpdateStateMachineAliasInputTypeDef,
    UpdateStateMachineAliasOutputTypeDef,
    UpdateStateMachineInputTypeDef,
    UpdateStateMachineOutputTypeDef,
    ValidateStateMachineDefinitionInputTypeDef,
    ValidateStateMachineDefinitionOutputTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Dict, Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack

__all__ = ("SFNClient",)

class Exceptions(BaseClientExceptions):
    ActivityAlreadyExists: Type[BotocoreClientError]
    ActivityDoesNotExist: Type[BotocoreClientError]
    ActivityLimitExceeded: Type[BotocoreClientError]
    ActivityWorkerLimitExceeded: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    ExecutionAlreadyExists: Type[BotocoreClientError]
    ExecutionDoesNotExist: Type[BotocoreClientError]
    ExecutionLimitExceeded: Type[BotocoreClientError]
    ExecutionNotRedrivable: Type[BotocoreClientError]
    InvalidArn: Type[BotocoreClientError]
    InvalidDefinition: Type[BotocoreClientError]
    InvalidEncryptionConfiguration: Type[BotocoreClientError]
    InvalidExecutionInput: Type[BotocoreClientError]
    InvalidLoggingConfiguration: Type[BotocoreClientError]
    InvalidName: Type[BotocoreClientError]
    InvalidOutput: Type[BotocoreClientError]
    InvalidToken: Type[BotocoreClientError]
    InvalidTracingConfiguration: Type[BotocoreClientError]
    KmsAccessDeniedException: Type[BotocoreClientError]
    KmsInvalidStateException: Type[BotocoreClientError]
    KmsThrottlingException: Type[BotocoreClientError]
    MissingRequiredParameter: Type[BotocoreClientError]
    ResourceNotFound: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    StateMachineAlreadyExists: Type[BotocoreClientError]
    StateMachineDeleting: Type[BotocoreClientError]
    StateMachineDoesNotExist: Type[BotocoreClientError]
    StateMachineLimitExceeded: Type[BotocoreClientError]
    StateMachineTypeNotSupported: Type[BotocoreClientError]
    TaskDoesNotExist: Type[BotocoreClientError]
    TaskTimedOut: Type[BotocoreClientError]
    TooManyTags: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]

class SFNClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions.html#SFN.Client)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        SFNClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions.html#SFN.Client)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/can_paginate.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/generate_presigned_url.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#generate_presigned_url)
        """

    def create_activity(
        self, **kwargs: Unpack[CreateActivityInputTypeDef]
    ) -> CreateActivityOutputTypeDef:
        """
        Creates an activity.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/create_activity.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#create_activity)
        """

    def create_state_machine(
        self, **kwargs: Unpack[CreateStateMachineInputTypeDef]
    ) -> CreateStateMachineOutputTypeDef:
        """
        Creates a state machine.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/create_state_machine.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#create_state_machine)
        """

    def create_state_machine_alias(
        self, **kwargs: Unpack[CreateStateMachineAliasInputTypeDef]
    ) -> CreateStateMachineAliasOutputTypeDef:
        """
        Creates an <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html">alias</a>
        for a state machine that points to one or two <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html">versions</a>
        of the same state mac...

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/create_state_machine_alias.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#create_state_machine_alias)
        """

    def delete_activity(self, **kwargs: Unpack[DeleteActivityInputTypeDef]) -> Dict[str, Any]:
        """
        Deletes an activity.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/delete_activity.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#delete_activity)
        """

    def delete_state_machine(
        self, **kwargs: Unpack[DeleteStateMachineInputTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes a state machine.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/delete_state_machine.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#delete_state_machine)
        """

    def delete_state_machine_alias(
        self, **kwargs: Unpack[DeleteStateMachineAliasInputTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes a state machine <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html">alias</a>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/delete_state_machine_alias.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#delete_state_machine_alias)
        """

    def delete_state_machine_version(
        self, **kwargs: Unpack[DeleteStateMachineVersionInputTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes a state machine <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html">version</a>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/delete_state_machine_version.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#delete_state_machine_version)
        """

    def describe_activity(
        self, **kwargs: Unpack[DescribeActivityInputTypeDef]
    ) -> DescribeActivityOutputTypeDef:
        """
        Describes an activity.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/describe_activity.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#describe_activity)
        """

    def describe_execution(
        self, **kwargs: Unpack[DescribeExecutionInputTypeDef]
    ) -> DescribeExecutionOutputTypeDef:
        """
        Provides information about a state machine execution, such as the state machine
        associated with the execution, the execution input and output, and relevant
        execution metadata.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/describe_execution.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#describe_execution)
        """

    def describe_map_run(
        self, **kwargs: Unpack[DescribeMapRunInputTypeDef]
    ) -> DescribeMapRunOutputTypeDef:
        """
        Provides information about a Map Run's configuration, progress, and results.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/describe_map_run.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#describe_map_run)
        """

    def describe_state_machine(
        self, **kwargs: Unpack[DescribeStateMachineInputTypeDef]
    ) -> DescribeStateMachineOutputTypeDef:
        """
        Provides information about a state machine's definition, its IAM role Amazon
        Resource Name (ARN), and configuration.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/describe_state_machine.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#describe_state_machine)
        """

    def describe_state_machine_alias(
        self, **kwargs: Unpack[DescribeStateMachineAliasInputTypeDef]
    ) -> DescribeStateMachineAliasOutputTypeDef:
        """
        Returns details about a state machine <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html">alias</a>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/describe_state_machine_alias.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#describe_state_machine_alias)
        """

    def describe_state_machine_for_execution(
        self, **kwargs: Unpack[DescribeStateMachineForExecutionInputTypeDef]
    ) -> DescribeStateMachineForExecutionOutputTypeDef:
        """
        Provides information about a state machine's definition, its execution role
        ARN, and configuration.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/describe_state_machine_for_execution.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#describe_state_machine_for_execution)
        """

    def get_activity_task(
        self, **kwargs: Unpack[GetActivityTaskInputTypeDef]
    ) -> GetActivityTaskOutputTypeDef:
        """
        Used by workers to retrieve a task (with the specified activity ARN) which has
        been scheduled for execution by a running state machine.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/get_activity_task.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#get_activity_task)
        """

    def get_execution_history(
        self, **kwargs: Unpack[GetExecutionHistoryInputTypeDef]
    ) -> GetExecutionHistoryOutputTypeDef:
        """
        Returns the history of the specified execution as a list of events.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/get_execution_history.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#get_execution_history)
        """

    def list_activities(
        self, **kwargs: Unpack[ListActivitiesInputTypeDef]
    ) -> ListActivitiesOutputTypeDef:
        """
        Lists the existing activities.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/list_activities.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#list_activities)
        """

    def list_executions(
        self, **kwargs: Unpack[ListExecutionsInputTypeDef]
    ) -> ListExecutionsOutputTypeDef:
        """
        Lists all executions of a state machine or a Map Run.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/list_executions.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#list_executions)
        """

    def list_map_runs(self, **kwargs: Unpack[ListMapRunsInputTypeDef]) -> ListMapRunsOutputTypeDef:
        """
        Lists all Map Runs that were started by a given state machine execution.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/list_map_runs.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#list_map_runs)
        """

    def list_state_machine_aliases(
        self, **kwargs: Unpack[ListStateMachineAliasesInputTypeDef]
    ) -> ListStateMachineAliasesOutputTypeDef:
        """
        Lists <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html">aliases</a>
        for a specified state machine ARN.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/list_state_machine_aliases.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#list_state_machine_aliases)
        """

    def list_state_machine_versions(
        self, **kwargs: Unpack[ListStateMachineVersionsInputTypeDef]
    ) -> ListStateMachineVersionsOutputTypeDef:
        """
        Lists <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html">versions</a>
        for the specified state machine Amazon Resource Name (ARN).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/list_state_machine_versions.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#list_state_machine_versions)
        """

    def list_state_machines(
        self, **kwargs: Unpack[ListStateMachinesInputTypeDef]
    ) -> ListStateMachinesOutputTypeDef:
        """
        Lists the existing state machines.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/list_state_machines.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#list_state_machines)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceInputTypeDef]
    ) -> ListTagsForResourceOutputTypeDef:
        """
        List tags for a given resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/list_tags_for_resource.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#list_tags_for_resource)
        """

    def publish_state_machine_version(
        self, **kwargs: Unpack[PublishStateMachineVersionInputTypeDef]
    ) -> PublishStateMachineVersionOutputTypeDef:
        """
        Creates a <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-version.html">version</a>
        from the current revision of a state machine.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/publish_state_machine_version.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#publish_state_machine_version)
        """

    def redrive_execution(
        self, **kwargs: Unpack[RedriveExecutionInputTypeDef]
    ) -> RedriveExecutionOutputTypeDef:
        """
        Restarts unsuccessful executions of Standard workflows that didn't complete
        successfully in the last 14 days.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/redrive_execution.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#redrive_execution)
        """

    def send_task_failure(self, **kwargs: Unpack[SendTaskFailureInputTypeDef]) -> Dict[str, Any]:
        """
        Used by activity workers, Task states using the <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-wait-token">callback</a>
        pattern, and optionally Task states using the <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.h...

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/send_task_failure.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#send_task_failure)
        """

    def send_task_heartbeat(
        self, **kwargs: Unpack[SendTaskHeartbeatInputTypeDef]
    ) -> Dict[str, Any]:
        """
        Used by activity workers and Task states using the <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-wait-token">callback</a>
        pattern, and optionally Task states using the <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resourc...

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/send_task_heartbeat.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#send_task_heartbeat)
        """

    def send_task_success(self, **kwargs: Unpack[SendTaskSuccessInputTypeDef]) -> Dict[str, Any]:
        """
        Used by activity workers, Task states using the <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.html#connect-wait-token">callback</a>
        pattern, and optionally Task states using the <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/connect-to-resource.h...

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/send_task_success.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#send_task_success)
        """

    def start_execution(
        self, **kwargs: Unpack[StartExecutionInputTypeDef]
    ) -> StartExecutionOutputTypeDef:
        """
        Starts a state machine execution.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/start_execution.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#start_execution)
        """

    def start_sync_execution(
        self, **kwargs: Unpack[StartSyncExecutionInputTypeDef]
    ) -> StartSyncExecutionOutputTypeDef:
        """
        Starts a Synchronous Express state machine execution.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/start_sync_execution.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#start_sync_execution)
        """

    def stop_execution(
        self, **kwargs: Unpack[StopExecutionInputTypeDef]
    ) -> StopExecutionOutputTypeDef:
        """
        Stops an execution.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/stop_execution.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#stop_execution)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceInputTypeDef]) -> Dict[str, Any]:
        """
        Add a tag to a Step Functions resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/tag_resource.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#tag_resource)
        """

    def test_state(self, **kwargs: Unpack[TestStateInputTypeDef]) -> TestStateOutputTypeDef:
        """
        Accepts the definition of a single state and executes it.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/test_state.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#test_state)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceInputTypeDef]) -> Dict[str, Any]:
        """
        Remove a tag from a Step Functions resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/untag_resource.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#untag_resource)
        """

    def update_map_run(self, **kwargs: Unpack[UpdateMapRunInputTypeDef]) -> Dict[str, Any]:
        """
        Updates an in-progress Map Run's configuration to include changes to the
        settings that control maximum concurrency and Map Run failure.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/update_map_run.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#update_map_run)
        """

    def update_state_machine(
        self, **kwargs: Unpack[UpdateStateMachineInputTypeDef]
    ) -> UpdateStateMachineOutputTypeDef:
        """
        Updates an existing state machine by modifying its <code>definition</code>,
        <code>roleArn</code>, <code>loggingConfiguration</code>, or
        <code>EncryptionConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/update_state_machine.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#update_state_machine)
        """

    def update_state_machine_alias(
        self, **kwargs: Unpack[UpdateStateMachineAliasInputTypeDef]
    ) -> UpdateStateMachineAliasOutputTypeDef:
        """
        Updates the configuration of an existing state machine <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-state-machine-alias.html">alias</a>
        by modifying its <code>description</code> or <code>routingConfiguration</code>.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/update_state_machine_alias.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#update_state_machine_alias)
        """

    def validate_state_machine_definition(
        self, **kwargs: Unpack[ValidateStateMachineDefinitionInputTypeDef]
    ) -> ValidateStateMachineDefinitionOutputTypeDef:
        """
        Validates the syntax of a state machine definition specified in <a
        href="https://docs.aws.amazon.com/step-functions/latest/dg/concepts-amazon-states-language.html">Amazon
        States Language</a> (ASL), a JSON-based, structured language.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/validate_state_machine_definition.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#validate_state_machine_definition)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["get_execution_history"]
    ) -> GetExecutionHistoryPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_activities"]
    ) -> ListActivitiesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_executions"]
    ) -> ListExecutionsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_map_runs"]
    ) -> ListMapRunsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_state_machines"]
    ) -> ListStateMachinesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/client/#get_paginator)
        """



"""
Type annotations for stepfunctions service client paginators.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from mypy_boto3_stepfunctions.client import SFNClient
    from mypy_boto3_stepfunctions.paginator import (
        GetExecutionHistoryPaginator,
        ListActivitiesPaginator,
        ListExecutionsPaginator,
        ListMapRunsPaginator,
        ListStateMachinesPaginator,
    )

    session = Session()
    client: SFNClient = session.client("stepfunctions")

    get_execution_history_paginator: GetExecutionHistoryPaginator = client.get_paginator("get_execution_history")
    list_activities_paginator: ListActivitiesPaginator = client.get_paginator("list_activities")
    list_executions_paginator: ListExecutionsPaginator = client.get_paginator("list_executions")
    list_map_runs_paginator: ListMapRunsPaginator = client.get_paginator("list_map_runs")
    list_state_machines_paginator: ListStateMachinesPaginator = client.get_paginator("list_state_machines")
    ```
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    GetExecutionHistoryInputPaginateTypeDef,
    GetExecutionHistoryOutputTypeDef,
    ListActivitiesInputPaginateTypeDef,
    ListActivitiesOutputTypeDef,
    ListExecutionsInputPaginateTypeDef,
    ListExecutionsOutputTypeDef,
    ListMapRunsInputPaginateTypeDef,
    ListMapRunsOutputTypeDef,
    ListStateMachinesInputPaginateTypeDef,
    ListStateMachinesOutputTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "GetExecutionHistoryPaginator",
    "ListActivitiesPaginator",
    "ListExecutionsPaginator",
    "ListMapRunsPaginator",
    "ListStateMachinesPaginator",
)


if TYPE_CHECKING:
    _GetExecutionHistoryPaginatorBase = Paginator[GetExecutionHistoryOutputTypeDef]
else:
    _GetExecutionHistoryPaginatorBase = Paginator  # type: ignore[assignment]


class GetExecutionHistoryPaginator(_GetExecutionHistoryPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/GetExecutionHistory.html#SFN.Paginator.GetExecutionHistory)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#getexecutionhistorypaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[GetExecutionHistoryInputPaginateTypeDef]
    ) -> PageIterator[GetExecutionHistoryOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/GetExecutionHistory.html#SFN.Paginator.GetExecutionHistory.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#getexecutionhistorypaginator)
        """


if TYPE_CHECKING:
    _ListActivitiesPaginatorBase = Paginator[ListActivitiesOutputTypeDef]
else:
    _ListActivitiesPaginatorBase = Paginator  # type: ignore[assignment]


class ListActivitiesPaginator(_ListActivitiesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/ListActivities.html#SFN.Paginator.ListActivities)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#listactivitiespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListActivitiesInputPaginateTypeDef]
    ) -> PageIterator[ListActivitiesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/ListActivities.html#SFN.Paginator.ListActivities.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#listactivitiespaginator)
        """


if TYPE_CHECKING:
    _ListExecutionsPaginatorBase = Paginator[ListExecutionsOutputTypeDef]
else:
    _ListExecutionsPaginatorBase = Paginator  # type: ignore[assignment]


class ListExecutionsPaginator(_ListExecutionsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/ListExecutions.html#SFN.Paginator.ListExecutions)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#listexecutionspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListExecutionsInputPaginateTypeDef]
    ) -> PageIterator[ListExecutionsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/ListExecutions.html#SFN.Paginator.ListExecutions.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#listexecutionspaginator)
        """


if TYPE_CHECKING:
    _ListMapRunsPaginatorBase = Paginator[ListMapRunsOutputTypeDef]
else:
    _ListMapRunsPaginatorBase = Paginator  # type: ignore[assignment]


class ListMapRunsPaginator(_ListMapRunsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/ListMapRuns.html#SFN.Paginator.ListMapRuns)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#listmaprunspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListMapRunsInputPaginateTypeDef]
    ) -> PageIterator[ListMapRunsOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/ListMapRuns.html#SFN.Paginator.ListMapRuns.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#listmaprunspaginator)
        """


if TYPE_CHECKING:
    _ListStateMachinesPaginatorBase = Paginator[ListStateMachinesOutputTypeDef]
else:
    _ListStateMachinesPaginatorBase = Paginator  # type: ignore[assignment]


class ListStateMachinesPaginator(_ListStateMachinesPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/ListStateMachines.html#SFN.Paginator.ListStateMachines)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#liststatemachinespaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListStateMachinesInputPaginateTypeDef]
    ) -> PageIterator[ListStateMachinesOutputTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/stepfunctions/paginator/ListStateMachines.html#SFN.Paginator.ListStateMachines.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/paginators/#liststatemachinespaginator)
        """



"""
Type annotations for stepfunctions service type definitions.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_stepfunctions/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from mypy_boto3_stepfunctions.type_defs import ActivityFailedEventDetailsTypeDef

    data: ActivityFailedEventDetailsTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Union

from .literals import (
    EncryptionTypeType,
    ExecutionRedriveFilterType,
    ExecutionRedriveStatusType,
    ExecutionStatusType,
    HistoryEventTypeType,
    IncludedDataType,
    InspectionLevelType,
    LogLevelType,
    MapRunStatusType,
    StateMachineStatusType,
    StateMachineTypeType,
    SyncExecutionStatusType,
    TestExecutionStatusType,
    ValidateStateMachineDefinitionResultCodeType,
    ValidateStateMachineDefinitionSeverityType,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Sequence
else:
    from typing import Dict, List, Sequence
if sys.version_info >= (3, 12):
    from typing import NotRequired, TypedDict
else:
    from typing_extensions import NotRequired, TypedDict

__all__ = (
    "ActivityFailedEventDetailsTypeDef",
    "ActivityListItemTypeDef",
    "ActivityScheduleFailedEventDetailsTypeDef",
    "ActivityScheduledEventDetailsTypeDef",
    "ActivityStartedEventDetailsTypeDef",
    "ActivitySucceededEventDetailsTypeDef",
    "ActivityTimedOutEventDetailsTypeDef",
    "AssignedVariablesDetailsTypeDef",
    "BillingDetailsTypeDef",
    "CloudWatchEventsExecutionDataDetailsTypeDef",
    "CloudWatchLogsLogGroupTypeDef",
    "CreateActivityInputTypeDef",
    "CreateActivityOutputTypeDef",
    "CreateStateMachineAliasInputTypeDef",
    "CreateStateMachineAliasOutputTypeDef",
    "CreateStateMachineInputTypeDef",
    "CreateStateMachineOutputTypeDef",
    "DeleteActivityInputTypeDef",
    "DeleteStateMachineAliasInputTypeDef",
    "DeleteStateMachineInputTypeDef",
    "DeleteStateMachineVersionInputTypeDef",
    "DescribeActivityInputTypeDef",
    "DescribeActivityOutputTypeDef",
    "DescribeExecutionInputTypeDef",
    "DescribeExecutionOutputTypeDef",
    "DescribeMapRunInputTypeDef",
    "DescribeMapRunOutputTypeDef",
    "DescribeStateMachineAliasInputTypeDef",
    "DescribeStateMachineAliasOutputTypeDef",
    "DescribeStateMachineForExecutionInputTypeDef",
    "DescribeStateMachineForExecutionOutputTypeDef",
    "DescribeStateMachineInputTypeDef",
    "DescribeStateMachineOutputTypeDef",
    "EncryptionConfigurationTypeDef",
    "EvaluationFailedEventDetailsTypeDef",
    "ExecutionAbortedEventDetailsTypeDef",
    "ExecutionFailedEventDetailsTypeDef",
    "ExecutionListItemTypeDef",
    "ExecutionRedrivenEventDetailsTypeDef",
    "ExecutionStartedEventDetailsTypeDef",
    "ExecutionSucceededEventDetailsTypeDef",
    "ExecutionTimedOutEventDetailsTypeDef",
    "GetActivityTaskInputTypeDef",
    "GetActivityTaskOutputTypeDef",
    "GetExecutionHistoryInputPaginateTypeDef",
    "GetExecutionHistoryInputTypeDef",
    "GetExecutionHistoryOutputTypeDef",
    "HistoryEventExecutionDataDetailsTypeDef",
    "HistoryEventTypeDef",
    "InspectionDataRequestTypeDef",
    "InspectionDataResponseTypeDef",
    "InspectionDataTypeDef",
    "LambdaFunctionFailedEventDetailsTypeDef",
    "LambdaFunctionScheduleFailedEventDetailsTypeDef",
    "LambdaFunctionScheduledEventDetailsTypeDef",
    "LambdaFunctionStartFailedEventDetailsTypeDef",
    "LambdaFunctionSucceededEventDetailsTypeDef",
    "LambdaFunctionTimedOutEventDetailsTypeDef",
    "ListActivitiesInputPaginateTypeDef",
    "ListActivitiesInputTypeDef",
    "ListActivitiesOutputTypeDef",
    "ListExecutionsInputPaginateTypeDef",
    "ListExecutionsInputTypeDef",
    "ListExecutionsOutputTypeDef",
    "ListMapRunsInputPaginateTypeDef",
    "ListMapRunsInputTypeDef",
    "ListMapRunsOutputTypeDef",
    "ListStateMachineAliasesInputTypeDef",
    "ListStateMachineAliasesOutputTypeDef",
    "ListStateMachineVersionsInputTypeDef",
    "ListStateMachineVersionsOutputTypeDef",
    "ListStateMachinesInputPaginateTypeDef",
    "ListStateMachinesInputTypeDef",
    "ListStateMachinesOutputTypeDef",
    "ListTagsForResourceInputTypeDef",
    "ListTagsForResourceOutputTypeDef",
    "LogDestinationTypeDef",
    "LoggingConfigurationOutputTypeDef",
    "LoggingConfigurationTypeDef",
    "LoggingConfigurationUnionTypeDef",
    "MapIterationEventDetailsTypeDef",
    "MapRunExecutionCountsTypeDef",
    "MapRunFailedEventDetailsTypeDef",
    "MapRunItemCountsTypeDef",
    "MapRunListItemTypeDef",
    "MapRunRedrivenEventDetailsTypeDef",
    "MapRunStartedEventDetailsTypeDef",
    "MapStateStartedEventDetailsTypeDef",
    "PaginatorConfigTypeDef",
    "PublishStateMachineVersionInputTypeDef",
    "PublishStateMachineVersionOutputTypeDef",
    "RedriveExecutionInputTypeDef",
    "RedriveExecutionOutputTypeDef",
    "ResponseMetadataTypeDef",
    "RoutingConfigurationListItemTypeDef",
    "SendTaskFailureInputTypeDef",
    "SendTaskHeartbeatInputTypeDef",
    "SendTaskSuccessInputTypeDef",
    "StartExecutionInputTypeDef",
    "StartExecutionOutputTypeDef",
    "StartSyncExecutionInputTypeDef",
    "StartSyncExecutionOutputTypeDef",
    "StateEnteredEventDetailsTypeDef",
    "StateExitedEventDetailsTypeDef",
    "StateMachineAliasListItemTypeDef",
    "StateMachineListItemTypeDef",
    "StateMachineVersionListItemTypeDef",
    "StopExecutionInputTypeDef",
    "StopExecutionOutputTypeDef",
    "TagResourceInputTypeDef",
    "TagTypeDef",
    "TaskCredentialsTypeDef",
    "TaskFailedEventDetailsTypeDef",
    "TaskScheduledEventDetailsTypeDef",
    "TaskStartFailedEventDetailsTypeDef",
    "TaskStartedEventDetailsTypeDef",
    "TaskSubmitFailedEventDetailsTypeDef",
    "TaskSubmittedEventDetailsTypeDef",
    "TaskSucceededEventDetailsTypeDef",
    "TaskTimedOutEventDetailsTypeDef",
    "TestStateInputTypeDef",
    "TestStateOutputTypeDef",
    "TracingConfigurationTypeDef",
    "UntagResourceInputTypeDef",
    "UpdateMapRunInputTypeDef",
    "UpdateStateMachineAliasInputTypeDef",
    "UpdateStateMachineAliasOutputTypeDef",
    "UpdateStateMachineInputTypeDef",
    "UpdateStateMachineOutputTypeDef",
    "ValidateStateMachineDefinitionDiagnosticTypeDef",
    "ValidateStateMachineDefinitionInputTypeDef",
    "ValidateStateMachineDefinitionOutputTypeDef",
)

class ActivityFailedEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class ActivityListItemTypeDef(TypedDict):
    activityArn: str
    name: str
    creationDate: datetime

class ActivityScheduleFailedEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class HistoryEventExecutionDataDetailsTypeDef(TypedDict):
    truncated: NotRequired[bool]

class ActivityStartedEventDetailsTypeDef(TypedDict):
    workerName: NotRequired[str]

class ActivityTimedOutEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class AssignedVariablesDetailsTypeDef(TypedDict):
    truncated: NotRequired[bool]

class BillingDetailsTypeDef(TypedDict):
    billedMemoryUsedInMB: NotRequired[int]
    billedDurationInMilliseconds: NotRequired[int]

class CloudWatchEventsExecutionDataDetailsTypeDef(TypedDict):
    included: NotRequired[bool]

class CloudWatchLogsLogGroupTypeDef(TypedDict):
    logGroupArn: NotRequired[str]

EncryptionConfigurationTypeDef = TypedDict(
    "EncryptionConfigurationTypeDef",
    {
        "type": EncryptionTypeType,
        "kmsKeyId": NotRequired[str],
        "kmsDataKeyReusePeriodSeconds": NotRequired[int],
    },
)

class TagTypeDef(TypedDict):
    key: NotRequired[str]
    value: NotRequired[str]

class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]

class RoutingConfigurationListItemTypeDef(TypedDict):
    stateMachineVersionArn: str
    weight: int

class TracingConfigurationTypeDef(TypedDict):
    enabled: NotRequired[bool]

class DeleteActivityInputTypeDef(TypedDict):
    activityArn: str

class DeleteStateMachineAliasInputTypeDef(TypedDict):
    stateMachineAliasArn: str

class DeleteStateMachineInputTypeDef(TypedDict):
    stateMachineArn: str

class DeleteStateMachineVersionInputTypeDef(TypedDict):
    stateMachineVersionArn: str

class DescribeActivityInputTypeDef(TypedDict):
    activityArn: str

class DescribeExecutionInputTypeDef(TypedDict):
    executionArn: str
    includedData: NotRequired[IncludedDataType]

class DescribeMapRunInputTypeDef(TypedDict):
    mapRunArn: str

class MapRunExecutionCountsTypeDef(TypedDict):
    pending: int
    running: int
    succeeded: int
    failed: int
    timedOut: int
    aborted: int
    total: int
    resultsWritten: int
    failuresNotRedrivable: NotRequired[int]
    pendingRedrive: NotRequired[int]

class MapRunItemCountsTypeDef(TypedDict):
    pending: int
    running: int
    succeeded: int
    failed: int
    timedOut: int
    aborted: int
    total: int
    resultsWritten: int
    failuresNotRedrivable: NotRequired[int]
    pendingRedrive: NotRequired[int]

class DescribeStateMachineAliasInputTypeDef(TypedDict):
    stateMachineAliasArn: str

class DescribeStateMachineForExecutionInputTypeDef(TypedDict):
    executionArn: str
    includedData: NotRequired[IncludedDataType]

class DescribeStateMachineInputTypeDef(TypedDict):
    stateMachineArn: str
    includedData: NotRequired[IncludedDataType]

class EvaluationFailedEventDetailsTypeDef(TypedDict):
    state: str
    error: NotRequired[str]
    cause: NotRequired[str]
    location: NotRequired[str]

class ExecutionAbortedEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class ExecutionFailedEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class ExecutionListItemTypeDef(TypedDict):
    executionArn: str
    stateMachineArn: str
    name: str
    status: ExecutionStatusType
    startDate: datetime
    stopDate: NotRequired[datetime]
    mapRunArn: NotRequired[str]
    itemCount: NotRequired[int]
    stateMachineVersionArn: NotRequired[str]
    stateMachineAliasArn: NotRequired[str]
    redriveCount: NotRequired[int]
    redriveDate: NotRequired[datetime]

class ExecutionRedrivenEventDetailsTypeDef(TypedDict):
    redriveCount: NotRequired[int]

class ExecutionTimedOutEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class GetActivityTaskInputTypeDef(TypedDict):
    activityArn: str
    workerName: NotRequired[str]

class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]

class GetExecutionHistoryInputTypeDef(TypedDict):
    executionArn: str
    maxResults: NotRequired[int]
    reverseOrder: NotRequired[bool]
    nextToken: NotRequired[str]
    includeExecutionData: NotRequired[bool]

class LambdaFunctionFailedEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class LambdaFunctionScheduleFailedEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class LambdaFunctionStartFailedEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class LambdaFunctionTimedOutEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class MapIterationEventDetailsTypeDef(TypedDict):
    name: NotRequired[str]
    index: NotRequired[int]

class MapRunFailedEventDetailsTypeDef(TypedDict):
    error: NotRequired[str]
    cause: NotRequired[str]

class MapRunRedrivenEventDetailsTypeDef(TypedDict):
    mapRunArn: NotRequired[str]
    redriveCount: NotRequired[int]

class MapRunStartedEventDetailsTypeDef(TypedDict):
    mapRunArn: NotRequired[str]

class MapStateStartedEventDetailsTypeDef(TypedDict):
    length: NotRequired[int]

class TaskFailedEventDetailsTypeDef(TypedDict):
    resourceType: str
    resource: str
    error: NotRequired[str]
    cause: NotRequired[str]

class TaskStartFailedEventDetailsTypeDef(TypedDict):
    resourceType: str
    resource: str
    error: NotRequired[str]
    cause: NotRequired[str]

class TaskStartedEventDetailsTypeDef(TypedDict):
    resourceType: str
    resource: str

class TaskSubmitFailedEventDetailsTypeDef(TypedDict):
    resourceType: str
    resource: str
    error: NotRequired[str]
    cause: NotRequired[str]

class TaskTimedOutEventDetailsTypeDef(TypedDict):
    resourceType: str
    resource: str
    error: NotRequired[str]
    cause: NotRequired[str]

class InspectionDataRequestTypeDef(TypedDict):
    protocol: NotRequired[str]
    method: NotRequired[str]
    url: NotRequired[str]
    headers: NotRequired[str]
    body: NotRequired[str]

class InspectionDataResponseTypeDef(TypedDict):
    protocol: NotRequired[str]
    statusCode: NotRequired[str]
    statusMessage: NotRequired[str]
    headers: NotRequired[str]
    body: NotRequired[str]

class TaskCredentialsTypeDef(TypedDict):
    roleArn: NotRequired[str]

class ListActivitiesInputTypeDef(TypedDict):
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]

class ListExecutionsInputTypeDef(TypedDict):
    stateMachineArn: NotRequired[str]
    statusFilter: NotRequired[ExecutionStatusType]
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]
    mapRunArn: NotRequired[str]
    redriveFilter: NotRequired[ExecutionRedriveFilterType]

class ListMapRunsInputTypeDef(TypedDict):
    executionArn: str
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]

class MapRunListItemTypeDef(TypedDict):
    executionArn: str
    mapRunArn: str
    stateMachineArn: str
    startDate: datetime
    stopDate: NotRequired[datetime]

class ListStateMachineAliasesInputTypeDef(TypedDict):
    stateMachineArn: str
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class StateMachineAliasListItemTypeDef(TypedDict):
    stateMachineAliasArn: str
    creationDate: datetime

class ListStateMachineVersionsInputTypeDef(TypedDict):
    stateMachineArn: str
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class StateMachineVersionListItemTypeDef(TypedDict):
    stateMachineVersionArn: str
    creationDate: datetime

class ListStateMachinesInputTypeDef(TypedDict):
    maxResults: NotRequired[int]
    nextToken: NotRequired[str]

StateMachineListItemTypeDef = TypedDict(
    "StateMachineListItemTypeDef",
    {
        "stateMachineArn": str,
        "name": str,
        "type": StateMachineTypeType,
        "creationDate": datetime,
    },
)

class ListTagsForResourceInputTypeDef(TypedDict):
    resourceArn: str

class PublishStateMachineVersionInputTypeDef(TypedDict):
    stateMachineArn: str
    revisionId: NotRequired[str]
    description: NotRequired[str]

class RedriveExecutionInputTypeDef(TypedDict):
    executionArn: str
    clientToken: NotRequired[str]

class SendTaskFailureInputTypeDef(TypedDict):
    taskToken: str
    error: NotRequired[str]
    cause: NotRequired[str]

class SendTaskHeartbeatInputTypeDef(TypedDict):
    taskToken: str

class SendTaskSuccessInputTypeDef(TypedDict):
    taskToken: str
    output: str

StartExecutionInputTypeDef = TypedDict(
    "StartExecutionInputTypeDef",
    {
        "stateMachineArn": str,
        "name": NotRequired[str],
        "input": NotRequired[str],
        "traceHeader": NotRequired[str],
    },
)
StartSyncExecutionInputTypeDef = TypedDict(
    "StartSyncExecutionInputTypeDef",
    {
        "stateMachineArn": str,
        "name": NotRequired[str],
        "input": NotRequired[str],
        "traceHeader": NotRequired[str],
        "includedData": NotRequired[IncludedDataType],
    },
)

class StopExecutionInputTypeDef(TypedDict):
    executionArn: str
    error: NotRequired[str]
    cause: NotRequired[str]

TestStateInputTypeDef = TypedDict(
    "TestStateInputTypeDef",
    {
        "definition": str,
        "roleArn": NotRequired[str],
        "input": NotRequired[str],
        "inspectionLevel": NotRequired[InspectionLevelType],
        "revealSecrets": NotRequired[bool],
        "variables": NotRequired[str],
    },
)

class UntagResourceInputTypeDef(TypedDict):
    resourceArn: str
    tagKeys: Sequence[str]

class UpdateMapRunInputTypeDef(TypedDict):
    mapRunArn: str
    maxConcurrency: NotRequired[int]
    toleratedFailurePercentage: NotRequired[float]
    toleratedFailureCount: NotRequired[int]

class ValidateStateMachineDefinitionDiagnosticTypeDef(TypedDict):
    severity: ValidateStateMachineDefinitionSeverityType
    code: str
    message: str
    location: NotRequired[str]

ValidateStateMachineDefinitionInputTypeDef = TypedDict(
    "ValidateStateMachineDefinitionInputTypeDef",
    {
        "definition": str,
        "type": NotRequired[StateMachineTypeType],
        "severity": NotRequired[ValidateStateMachineDefinitionSeverityType],
        "maxResults": NotRequired[int],
    },
)
ActivityScheduledEventDetailsTypeDef = TypedDict(
    "ActivityScheduledEventDetailsTypeDef",
    {
        "resource": str,
        "input": NotRequired[str],
        "inputDetails": NotRequired[HistoryEventExecutionDataDetailsTypeDef],
        "timeoutInSeconds": NotRequired[int],
        "heartbeatInSeconds": NotRequired[int],
    },
)

class ActivitySucceededEventDetailsTypeDef(TypedDict):
    output: NotRequired[str]
    outputDetails: NotRequired[HistoryEventExecutionDataDetailsTypeDef]

ExecutionStartedEventDetailsTypeDef = TypedDict(
    "ExecutionStartedEventDetailsTypeDef",
    {
        "input": NotRequired[str],
        "inputDetails": NotRequired[HistoryEventExecutionDataDetailsTypeDef],
        "roleArn": NotRequired[str],
        "stateMachineAliasArn": NotRequired[str],
        "stateMachineVersionArn": NotRequired[str],
    },
)

class ExecutionSucceededEventDetailsTypeDef(TypedDict):
    output: NotRequired[str]
    outputDetails: NotRequired[HistoryEventExecutionDataDetailsTypeDef]

class LambdaFunctionSucceededEventDetailsTypeDef(TypedDict):
    output: NotRequired[str]
    outputDetails: NotRequired[HistoryEventExecutionDataDetailsTypeDef]

StateEnteredEventDetailsTypeDef = TypedDict(
    "StateEnteredEventDetailsTypeDef",
    {
        "name": str,
        "input": NotRequired[str],
        "inputDetails": NotRequired[HistoryEventExecutionDataDetailsTypeDef],
    },
)

class TaskSubmittedEventDetailsTypeDef(TypedDict):
    resourceType: str
    resource: str
    output: NotRequired[str]
    outputDetails: NotRequired[HistoryEventExecutionDataDetailsTypeDef]

class TaskSucceededEventDetailsTypeDef(TypedDict):
    resourceType: str
    resource: str
    output: NotRequired[str]
    outputDetails: NotRequired[HistoryEventExecutionDataDetailsTypeDef]

class StateExitedEventDetailsTypeDef(TypedDict):
    name: str
    output: NotRequired[str]
    outputDetails: NotRequired[HistoryEventExecutionDataDetailsTypeDef]
    assignedVariables: NotRequired[Dict[str, str]]
    assignedVariablesDetails: NotRequired[AssignedVariablesDetailsTypeDef]

class LogDestinationTypeDef(TypedDict):
    cloudWatchLogsLogGroup: NotRequired[CloudWatchLogsLogGroupTypeDef]

class CreateActivityInputTypeDef(TypedDict):
    name: str
    tags: NotRequired[Sequence[TagTypeDef]]
    encryptionConfiguration: NotRequired[EncryptionConfigurationTypeDef]

class TagResourceInputTypeDef(TypedDict):
    resourceArn: str
    tags: Sequence[TagTypeDef]

class CreateActivityOutputTypeDef(TypedDict):
    activityArn: str
    creationDate: datetime
    ResponseMetadata: ResponseMetadataTypeDef

class CreateStateMachineAliasOutputTypeDef(TypedDict):
    stateMachineAliasArn: str
    creationDate: datetime
    ResponseMetadata: ResponseMetadataTypeDef

class CreateStateMachineOutputTypeDef(TypedDict):
    stateMachineArn: str
    creationDate: datetime
    stateMachineVersionArn: str
    ResponseMetadata: ResponseMetadataTypeDef

class DescribeActivityOutputTypeDef(TypedDict):
    activityArn: str
    name: str
    creationDate: datetime
    encryptionConfiguration: EncryptionConfigurationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

DescribeExecutionOutputTypeDef = TypedDict(
    "DescribeExecutionOutputTypeDef",
    {
        "executionArn": str,
        "stateMachineArn": str,
        "name": str,
        "status": ExecutionStatusType,
        "startDate": datetime,
        "input": str,
        "inputDetails": CloudWatchEventsExecutionDataDetailsTypeDef,
        "redriveCount": int,
        "redriveStatus": ExecutionRedriveStatusType,
        "ResponseMetadata": ResponseMetadataTypeDef,
        "stopDate": NotRequired[datetime],
        "output": NotRequired[str],
        "outputDetails": NotRequired[CloudWatchEventsExecutionDataDetailsTypeDef],
        "traceHeader": NotRequired[str],
        "mapRunArn": NotRequired[str],
        "error": NotRequired[str],
        "cause": NotRequired[str],
        "stateMachineVersionArn": NotRequired[str],
        "stateMachineAliasArn": NotRequired[str],
        "redriveDate": NotRequired[datetime],
        "redriveStatusReason": NotRequired[str],
    },
)
GetActivityTaskOutputTypeDef = TypedDict(
    "GetActivityTaskOutputTypeDef",
    {
        "taskToken": str,
        "input": str,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

class ListActivitiesOutputTypeDef(TypedDict):
    activities: List[ActivityListItemTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListTagsForResourceOutputTypeDef(TypedDict):
    tags: List[TagTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef

class PublishStateMachineVersionOutputTypeDef(TypedDict):
    creationDate: datetime
    stateMachineVersionArn: str
    ResponseMetadata: ResponseMetadataTypeDef

class RedriveExecutionOutputTypeDef(TypedDict):
    redriveDate: datetime
    ResponseMetadata: ResponseMetadataTypeDef

class StartExecutionOutputTypeDef(TypedDict):
    executionArn: str
    startDate: datetime
    ResponseMetadata: ResponseMetadataTypeDef

StartSyncExecutionOutputTypeDef = TypedDict(
    "StartSyncExecutionOutputTypeDef",
    {
        "executionArn": str,
        "stateMachineArn": str,
        "name": str,
        "startDate": datetime,
        "stopDate": datetime,
        "status": SyncExecutionStatusType,
        "error": str,
        "cause": str,
        "input": str,
        "inputDetails": CloudWatchEventsExecutionDataDetailsTypeDef,
        "output": str,
        "outputDetails": CloudWatchEventsExecutionDataDetailsTypeDef,
        "traceHeader": str,
        "billingDetails": BillingDetailsTypeDef,
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)

class StopExecutionOutputTypeDef(TypedDict):
    stopDate: datetime
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateStateMachineAliasOutputTypeDef(TypedDict):
    updateDate: datetime
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateStateMachineOutputTypeDef(TypedDict):
    updateDate: datetime
    revisionId: str
    stateMachineVersionArn: str
    ResponseMetadata: ResponseMetadataTypeDef

class CreateStateMachineAliasInputTypeDef(TypedDict):
    name: str
    routingConfiguration: Sequence[RoutingConfigurationListItemTypeDef]
    description: NotRequired[str]

class DescribeStateMachineAliasOutputTypeDef(TypedDict):
    stateMachineAliasArn: str
    name: str
    description: str
    routingConfiguration: List[RoutingConfigurationListItemTypeDef]
    creationDate: datetime
    updateDate: datetime
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateStateMachineAliasInputTypeDef(TypedDict):
    stateMachineAliasArn: str
    description: NotRequired[str]
    routingConfiguration: NotRequired[Sequence[RoutingConfigurationListItemTypeDef]]

class DescribeMapRunOutputTypeDef(TypedDict):
    mapRunArn: str
    executionArn: str
    status: MapRunStatusType
    startDate: datetime
    stopDate: datetime
    maxConcurrency: int
    toleratedFailurePercentage: float
    toleratedFailureCount: int
    itemCounts: MapRunItemCountsTypeDef
    executionCounts: MapRunExecutionCountsTypeDef
    redriveCount: int
    redriveDate: datetime
    ResponseMetadata: ResponseMetadataTypeDef

class ListExecutionsOutputTypeDef(TypedDict):
    executions: List[ExecutionListItemTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class GetExecutionHistoryInputPaginateTypeDef(TypedDict):
    executionArn: str
    reverseOrder: NotRequired[bool]
    includeExecutionData: NotRequired[bool]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListActivitiesInputPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListExecutionsInputPaginateTypeDef(TypedDict):
    stateMachineArn: NotRequired[str]
    statusFilter: NotRequired[ExecutionStatusType]
    mapRunArn: NotRequired[str]
    redriveFilter: NotRequired[ExecutionRedriveFilterType]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListMapRunsInputPaginateTypeDef(TypedDict):
    executionArn: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListStateMachinesInputPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

InspectionDataTypeDef = TypedDict(
    "InspectionDataTypeDef",
    {
        "input": NotRequired[str],
        "afterArguments": NotRequired[str],
        "afterInputPath": NotRequired[str],
        "afterParameters": NotRequired[str],
        "result": NotRequired[str],
        "afterResultSelector": NotRequired[str],
        "afterResultPath": NotRequired[str],
        "request": NotRequired[InspectionDataRequestTypeDef],
        "response": NotRequired[InspectionDataResponseTypeDef],
        "variables": NotRequired[str],
    },
)
LambdaFunctionScheduledEventDetailsTypeDef = TypedDict(
    "LambdaFunctionScheduledEventDetailsTypeDef",
    {
        "resource": str,
        "input": NotRequired[str],
        "inputDetails": NotRequired[HistoryEventExecutionDataDetailsTypeDef],
        "timeoutInSeconds": NotRequired[int],
        "taskCredentials": NotRequired[TaskCredentialsTypeDef],
    },
)

class TaskScheduledEventDetailsTypeDef(TypedDict):
    resourceType: str
    resource: str
    region: str
    parameters: str
    timeoutInSeconds: NotRequired[int]
    heartbeatInSeconds: NotRequired[int]
    taskCredentials: NotRequired[TaskCredentialsTypeDef]

class ListMapRunsOutputTypeDef(TypedDict):
    mapRuns: List[MapRunListItemTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListStateMachineAliasesOutputTypeDef(TypedDict):
    stateMachineAliases: List[StateMachineAliasListItemTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListStateMachineVersionsOutputTypeDef(TypedDict):
    stateMachineVersions: List[StateMachineVersionListItemTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListStateMachinesOutputTypeDef(TypedDict):
    stateMachines: List[StateMachineListItemTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ValidateStateMachineDefinitionOutputTypeDef(TypedDict):
    result: ValidateStateMachineDefinitionResultCodeType
    diagnostics: List[ValidateStateMachineDefinitionDiagnosticTypeDef]
    truncated: bool
    ResponseMetadata: ResponseMetadataTypeDef

class LoggingConfigurationOutputTypeDef(TypedDict):
    level: NotRequired[LogLevelType]
    includeExecutionData: NotRequired[bool]
    destinations: NotRequired[List[LogDestinationTypeDef]]

class LoggingConfigurationTypeDef(TypedDict):
    level: NotRequired[LogLevelType]
    includeExecutionData: NotRequired[bool]
    destinations: NotRequired[Sequence[LogDestinationTypeDef]]

class TestStateOutputTypeDef(TypedDict):
    output: str
    error: str
    cause: str
    inspectionData: InspectionDataTypeDef
    nextState: str
    status: TestExecutionStatusType
    ResponseMetadata: ResponseMetadataTypeDef

HistoryEventTypeDef = TypedDict(
    "HistoryEventTypeDef",
    {
        "timestamp": datetime,
        "type": HistoryEventTypeType,
        "id": int,
        "previousEventId": NotRequired[int],
        "activityFailedEventDetails": NotRequired[ActivityFailedEventDetailsTypeDef],
        "activityScheduleFailedEventDetails": NotRequired[
            ActivityScheduleFailedEventDetailsTypeDef
        ],
        "activityScheduledEventDetails": NotRequired[ActivityScheduledEventDetailsTypeDef],
        "activityStartedEventDetails": NotRequired[ActivityStartedEventDetailsTypeDef],
        "activitySucceededEventDetails": NotRequired[ActivitySucceededEventDetailsTypeDef],
        "activityTimedOutEventDetails": NotRequired[ActivityTimedOutEventDetailsTypeDef],
        "taskFailedEventDetails": NotRequired[TaskFailedEventDetailsTypeDef],
        "taskScheduledEventDetails": NotRequired[TaskScheduledEventDetailsTypeDef],
        "taskStartFailedEventDetails": NotRequired[TaskStartFailedEventDetailsTypeDef],
        "taskStartedEventDetails": NotRequired[TaskStartedEventDetailsTypeDef],
        "taskSubmitFailedEventDetails": NotRequired[TaskSubmitFailedEventDetailsTypeDef],
        "taskSubmittedEventDetails": NotRequired[TaskSubmittedEventDetailsTypeDef],
        "taskSucceededEventDetails": NotRequired[TaskSucceededEventDetailsTypeDef],
        "taskTimedOutEventDetails": NotRequired[TaskTimedOutEventDetailsTypeDef],
        "executionFailedEventDetails": NotRequired[ExecutionFailedEventDetailsTypeDef],
        "executionStartedEventDetails": NotRequired[ExecutionStartedEventDetailsTypeDef],
        "executionSucceededEventDetails": NotRequired[ExecutionSucceededEventDetailsTypeDef],
        "executionAbortedEventDetails": NotRequired[ExecutionAbortedEventDetailsTypeDef],
        "executionTimedOutEventDetails": NotRequired[ExecutionTimedOutEventDetailsTypeDef],
        "executionRedrivenEventDetails": NotRequired[ExecutionRedrivenEventDetailsTypeDef],
        "mapStateStartedEventDetails": NotRequired[MapStateStartedEventDetailsTypeDef],
        "mapIterationStartedEventDetails": NotRequired[MapIterationEventDetailsTypeDef],
        "mapIterationSucceededEventDetails": NotRequired[MapIterationEventDetailsTypeDef],
        "mapIterationFailedEventDetails": NotRequired[MapIterationEventDetailsTypeDef],
        "mapIterationAbortedEventDetails": NotRequired[MapIterationEventDetailsTypeDef],
        "lambdaFunctionFailedEventDetails": NotRequired[LambdaFunctionFailedEventDetailsTypeDef],
        "lambdaFunctionScheduleFailedEventDetails": NotRequired[
            LambdaFunctionScheduleFailedEventDetailsTypeDef
        ],
        "lambdaFunctionScheduledEventDetails": NotRequired[
            LambdaFunctionScheduledEventDetailsTypeDef
        ],
        "lambdaFunctionStartFailedEventDetails": NotRequired[
            LambdaFunctionStartFailedEventDetailsTypeDef
        ],
        "lambdaFunctionSucceededEventDetails": NotRequired[
            LambdaFunctionSucceededEventDetailsTypeDef
        ],
        "lambdaFunctionTimedOutEventDetails": NotRequired[
            LambdaFunctionTimedOutEventDetailsTypeDef
        ],
        "stateEnteredEventDetails": NotRequired[StateEnteredEventDetailsTypeDef],
        "stateExitedEventDetails": NotRequired[StateExitedEventDetailsTypeDef],
        "mapRunStartedEventDetails": NotRequired[MapRunStartedEventDetailsTypeDef],
        "mapRunFailedEventDetails": NotRequired[MapRunFailedEventDetailsTypeDef],
        "mapRunRedrivenEventDetails": NotRequired[MapRunRedrivenEventDetailsTypeDef],
        "evaluationFailedEventDetails": NotRequired[EvaluationFailedEventDetailsTypeDef],
    },
)

class DescribeStateMachineForExecutionOutputTypeDef(TypedDict):
    stateMachineArn: str
    name: str
    definition: str
    roleArn: str
    updateDate: datetime
    loggingConfiguration: LoggingConfigurationOutputTypeDef
    tracingConfiguration: TracingConfigurationTypeDef
    mapRunArn: str
    label: str
    revisionId: str
    encryptionConfiguration: EncryptionConfigurationTypeDef
    variableReferences: Dict[str, List[str]]
    ResponseMetadata: ResponseMetadataTypeDef

DescribeStateMachineOutputTypeDef = TypedDict(
    "DescribeStateMachineOutputTypeDef",
    {
        "stateMachineArn": str,
        "name": str,
        "status": StateMachineStatusType,
        "definition": str,
        "roleArn": str,
        "type": StateMachineTypeType,
        "creationDate": datetime,
        "loggingConfiguration": LoggingConfigurationOutputTypeDef,
        "tracingConfiguration": TracingConfigurationTypeDef,
        "label": str,
        "revisionId": str,
        "description": str,
        "encryptionConfiguration": EncryptionConfigurationTypeDef,
        "variableReferences": Dict[str, List[str]],
        "ResponseMetadata": ResponseMetadataTypeDef,
    },
)
LoggingConfigurationUnionTypeDef = Union[
    LoggingConfigurationTypeDef, LoggingConfigurationOutputTypeDef
]

class GetExecutionHistoryOutputTypeDef(TypedDict):
    events: List[HistoryEventTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

CreateStateMachineInputTypeDef = TypedDict(
    "CreateStateMachineInputTypeDef",
    {
        "name": str,
        "definition": str,
        "roleArn": str,
        "type": NotRequired[StateMachineTypeType],
        "loggingConfiguration": NotRequired[LoggingConfigurationUnionTypeDef],
        "tags": NotRequired[Sequence[TagTypeDef]],
        "tracingConfiguration": NotRequired[TracingConfigurationTypeDef],
        "publish": NotRequired[bool],
        "versionDescription": NotRequired[str],
        "encryptionConfiguration": NotRequired[EncryptionConfigurationTypeDef],
    },
)

class UpdateStateMachineInputTypeDef(TypedDict):
    stateMachineArn: str
    definition: NotRequired[str]
    roleArn: NotRequired[str]
    loggingConfiguration: NotRequired[LoggingConfigurationUnionTypeDef]
    tracingConfiguration: NotRequired[TracingConfigurationTypeDef]
    publish: NotRequired[bool]
    versionDescription: NotRequired[str]
    encryptionConfiguration: NotRequired[EncryptionConfigurationTypeDef]
